@@ -4,7 +4,7 @@ from typing import Iterable, Optional, Tuple
 
 from attr import attrib, attrs
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 
 Command = Tuple[str, ...]
@@ -37,7 +37,7 @@ class CommandTool:
 
 
 TOOLS = [
-    CommandTool('flake8'),
+    CommandTool('flake8', default_files=()),
     CommandTool(
         'isort', run_params=('-c',), fix_params=tuple(), default_files=('.',)
     ),
@@ -64,7 +64,7 @@ def execute_tools(fix: bool, files: Tuple[str, ...]) -> Iterable[bool]:
                 if fix and tool.fix_params is not None
                 else tool.run_command()
             )
-            if tool.default_files:
+            if tool.default_files is not None:
                 cmd = cmd + (files or tool.default_files)
             subprocess.run(args=cmd, check=True)
         except subprocess.CalledProcessError:
@@ -99,6 +99,10 @@ def get_changed_files() -> Iterable[str]:
 
 def main() -> None:
     args = make_arg_parser().parse_args()
+    if args.version:
+        print(f"lintlizard v{__version__}")
+        return
+
     files = list(args.files) or []
 
     if args.changed:
@@ -119,6 +123,7 @@ def make_arg_parser():
     parser = argparse.ArgumentParser()
     parser.add_argument('--fix', action='store_true')
     parser.add_argument('--changed', action='store_true')
+    parser.add_argument('--version', action='store_true')
     parser.add_argument('files', nargs='*', default=None)
 
     return parser
